const PLAYER_FACADE_VERSION = '2.0';

/**
 * A player proxy class
 * (last change 2018-12-13T10:45:57.548Z)
 * @module FacadeBase
 * @class
 */
export class FacadeBase {

	constructor(playerReference = {}) {
		this.player = playerReference;
		this.currentContentSource = {};

		/**
		 * Map player specific events to the corresponding HTML5 MediaEvent
		 * @return {{ended: string, loadeddata: string, timeupdate: string}}
		 */
		this.PLAYER_EVENT_MAP = {
			'ended': 'ended',
			'loadeddata': 'loadeddata',
			'timeupdate': 'timeupdate'
		};
	}

	/**
	 * Requests the player facade version (API version) to ensure the particular versions of `smartclientcore` and player facade
	 * are supported.
	 * @param {string} apiFacadeVersion - Required API version
	 * @returns {string} Supported API version
	 */
	handshakeVersion(apiFacadeVersion) {
		return PLAYER_FACADE_VERSION;
	}

	/**
	 * Requests the video player to load and play the specified media file.
	 * @param {string} url - Media file URI
	 * @param {Boolean} autoPlay - Whether the requested media file starts playback immediately.
	 * @param {Boolean} disableSeeking - Whether the requested source can be seeked back and forth.
	 * @returns {Promise} Resolves if the player accepted the media file request
	 */
	load(url, autoPlay = true, disableSeeking = false) {}

	/**
	 * Sets up a function that will be called whenever the specified event is delivered to the video player.
	 * @param {string} type - A case-sensitive string representing the player event type to listen for.
	 * @param {Function} callback - The function which receives a notification when an event of the specified type occurs.
	 */
	addEventListener(type, callback) {}

	/**
	 * Removes an event listener from the video player that has been registered with `addEventListener()`
	 * _*Note:* The event listener to be removed must match with the listener that has been added._
	 * @param {string} type - A case-sensitive string representing the player event type to listen for.
	 * @param {Function} callback - The function which receives a notification when an event of the specified type occurs.
	 */
	removeEventListener(type, callback) {}

	/**
	 * Requests the video player to lock the current content.
	 * _This happens before starting a new ad break_
	 * @returns {SourceObject} Current content source and playhead progress
	 */
	setCurrentContentSource() {}

	/**
	 * @returns {SourceObject} Current content source and playhead progress
	 */
	getCurrentContentSource() {}

	/**
	 * Requests the video player to return to the content and last known playhead position.
	 * @returns {Promise} Resolves if the player accepted the request
	 */
	resetCurrentContentSource() {}

	/**
	 * Requests the current playhead position from the video player.
	 * @returns {Number} Current time in seconds.
	 */
	getCurrentTime() {}

	/**
	 * Requests the content-duration from the video player.
	 * @returns {Number} Total time in seconds.
	 */
	getDuration() {}

	getVideoElement() {}

	/**
	 * Requests the video player to change the volume.
	 * @param {Number} volume - Requested volume level between 0-1
	 * @returns {Promise} Resolves if the video player accepted the volume change request
	 */
	setVolume(volume) {}

	/**
	 * Requests the current volume level from the video player.
	 * @returns {Number} The current volume level between 0-1
	 */
	getVolume() {}

	/**
	 * Requests the current muted state from the video player.
	 * @returns {Boolean} Muted state
	 */
	isMuted() {}

	/**
	 * Requests the video player to mute playback.
	 * @returns {Promise} Resolves if the video player has been muted
	 */
	mute() {}

	/**
	 * Requests the video player to unmute playback.
	 * @returns {Promise} Resolves if the video player has been unmuted
	 */
	unmute() {}

	/**
	 * Requests the current play state from the video player.
	 * @returns {Boolean} Playback state
	 */
	isPaused() {}

	/**
	 * Requests the video player to pause playback.
	 * @returns {Promise} Resolves if the video player has been paused
	 */
	pause() {}

	/**
	 * Requests the video player to start (resume) playback.
	 * @returns {Promise} Resolves if the video player has been resumed
	 */
	play() {}

	/**
	 * Requests the video player to change the playhead position to the specified time.
	 * @param {Number} offset - Requested playhead position
	 * @returns {Promise} Resolves if the video player has finished seeking to the specified position
	 */
	seek(offset) {}
}
